==> lightning-0.8.1.tar.gz: lib/src/view/components/l_utilities.dart <==
/*
 * Copyright (c) 2015 Accorto, Inc. All Rights Reserved
 * License: GPLv3  http://www.gnu.org/licenses/gpl-3.0.txt
 * License options+support:  https://lightningdart.com
 */

part of lightning_dart;


/// Floats
class LFloat {

  /// slds-float--left - Pulls element from document flow and floats left
  static const String C_FLOAT__LEFT = "slds-float--left";
  /// slds-float--right - Pulls element from document flow and floats right
  static const String C_FLOAT__RIGHT = "slds-float--right";
  /// slds-clearfix - Contains floats
  static const String C_CLEARFIX = "slds-clearfix";

} // LFloat


/// Sizing
class LSizing {

  static const String C_SIZE__1_OF_1 = "slds-size--1-of-1";

  static const String C_SIZE__1_OF_2 = "slds-size--1-of-2";

  static const String C_SIZE__1_OF_3 = "slds-size--1-of-3";
  static const String C_SIZE__2_OF_3 = "slds-size--2-of-3";

  static const String C_SIZE__1_OF_4 = "slds-size--1-of-4";
  static const String C_SIZE__2_OF_4 = "slds-size--2-of-4";
  static const String C_SIZE__3_OF_4 = "slds-size--3-of-4";

  static const String C_SIZE__1_OF_5 = "slds-size--1-of-5";
  static const String C_SIZE__2_OF_5 = "slds-size--2-of-5";
  static const String C_SIZE__3_OF_5 = "slds-size--3-of-5";
  static const String C_SIZE__4_OF_5 = "slds-size--4-of-5";

  static const String C_SIZE__1_OF_6 = "slds-size--1-of-6";
  static const String C_SIZE__2_OF_6 = "slds-size--2-of-6";
  static const String C_SIZE__3_OF_6 = "slds-size--3-of-6";
  static const String C_SIZE__4_OF_6 = "slds-size--4-of-6";
  static const String C_SIZE__5_OF_6 = "slds-size--5-of-6";

  static const String C_SIZE__1_OF_12 = "slds-size--1-of-12";
  static const String C_SIZE__2_OF_12 = "slds-size--2-of-12";
  static const String C_SIZE__3_OF_12 = "slds-size--3-of-12";
  static const String C_SIZE__4_OF_12 = "slds-size--4-of-12";
  static const String C_SIZE__5_OF_12 = "slds-size--5-of-12";
  static const String C_SIZE__6_OF_12 = "slds-size--6-of-12";
  static const String C_SIZE__7_OF_12 = "slds-size--7-of-12";
  static const String C_SIZE__8_OF_12 = "slds-size--8-of-12";
  static const String C_SIZE__9_OF_12 = "slds-size--9-of-12";
  static const String C_SIZE__10_OF_12 = "slds-size--10-of-12";
  static const String C_SIZE__11_OF_12 = "slds-size--11-of-12";

} // LSizing


/**
 * Margin
 */
class LMargin {

  static const String C_TOP__XXX_SMALL = "slds-m-top--xxx-small";
  static const String C_TOP__XX_SMALL = "slds-m-top--xx-small";
  static const String C_TOP__X_SMALL = "slds-m-top--x-small";
  static const String C_TOP__SMALL = "slds-m-top--small";
  static const String C_TOP__MEDIUM = "slds-m-top--medium";
  static const String C_TOP__LARGE = "slds-m-top--large";
  static const String C_TOP__X_LARGE = "slds-m-top--x-large";
  static const String C_RIGHT__XXX_SMALL = "slds-m-right--xxx-small";
  static const String C_RIGHT__XX_SMALL = "slds-m-right--xx-small";
  static const String C_RIGHT__X_SMALL = "slds-m-right--x-small";
  static const String C_RIGHT__SMALL = "slds-m-right--small";
  static const String C_RIGHT__MEDIUM = "slds-m-right--medium";
  static const String C_RIGHT__LARGE = "slds-m-right--large";
  static const String C_RIGHT__X_LARGE = "slds-m-right--x-large";
  static const String C_BOTTOM__XXX_SMALL = "slds-m-bottom--xxx-small";
  static const String C_BOTTOM__XX_SMALL = "slds-m-bottom--xx-small";
  static const String C_BOTTOM__X_SMALL = "slds-m-bottom--x-small";
  static const String C_BOTTOM__SMALL = "slds-m-bottom--small";
  static const String C_BOTTOM__MEDIUM = "slds-m-bottom--medium";
  static const String C_BOTTOM__LARGE = "slds-m-bottom--large";
  static const String C_BOTTOM__X_LARGE = "slds-m-bottom--x-large";
  static const String C_LEFT__XXX_SMALL = "slds-m-left--xxx-small";
  static const String C_LEFT__XX_SMALL = "slds-m-left--xx-small";
  static const String C_LEFT__X_SMALL = "slds-m-left--x-small";
  static const String C_LEFT__SMALL = "slds-m-left--small";
  static const String C_LEFT__MEDIUM = "slds-m-left--medium";
  static const String C_LEFT__LARGE = "slds-m-left--large";
  static const String C_LEFT__X_LARGE = "slds-m-left--x-large";
  static const String C_VERTICAL__XXX_SMALL = "slds-m-vertical--xxx-small";
  static const String C_VERTICAL__XX_SMALL = "slds-m-vertical--xx-small";
  static const String C_VERTICAL__X_SMALL = "slds-m-vertical--x-small";
  static const String C_VERTICAL__SMALL = "slds-m-vertical--small";
  static const String C_VERTICAL__MEDIUM = "slds-m-vertical--medium";
  static const String C_VERTICAL__LARGE = "slds-m-vertical--large";
  static const String C_VERTICAL__X_LARGE = "slds-m-vertical--x-large";
  static const String C_HORIZONTAL__XXX_SMALL = "slds-m-horizontal--xxx-small";
  static const String C_HORIZONTAL__XX_SMALL = "slds-m-horizontal--xx-small";
  static const String C_HORIZONTAL__X_SMALL = "slds-m-horizontal--x-small";
  static const String C_HORIZONTAL__SMALL = "slds-m-horizontal--small";
  static const String C_HORIZONTAL__MEDIUM = "slds-m-horizontal--medium";
  static const String C_HORIZONTAL__LARGE = "slds-m-horizontal--large";
  static const String C_HORIZONTAL__X_LARGE = "slds-m-horizontal--x-large";
  static const String C_AROUND__XXX_SMALL = "slds-m-around--xxx-small";
  static const String C_AROUND__XX_SMALL = "slds-m-around--xx-small";
  static const String C_AROUND__X_SMALL = "slds-m-around--x-small";
  static const String C_AROUND__SMALL = "slds-m-around--small";
  static const String C_AROUND__MEDIUM = "slds-m-around--medium";
  static const String C_AROUND__LARGE = "slds-m-around--large";
  static const String C_AROUND__X_LARGE = "slds-m-around--x-large";

} // LMargin


/**
 * Padding
 */
class LPadding {

  static const String C_TOP__XXX_SMALL = "slds-p-top--xxx-small";
  static const String C_TOP__XX_SMALL = "slds-p-top--xx-small";
  static const String C_TOP__X_SMALL = "slds-p-top--x-small";
  static const String C_TOP__SMALL = "slds-p-top--small";
  static const String C_TOP__MEDIUM = "slds-p-top--medium";
  static const String C_TOP__LARGE = "slds-p-top--large";
  static const String C_TOP__X_LARGE = "slds-p-top--x-large";
  static const String C_RIGHT__XXX_SMALL = "slds-p-right--xxx-small";
  static const String C_RIGHT__XX_SMALL = "slds-p-right--xx-small";
  static const String C_RIGHT__X_SMALL = "slds-p-right--x-small";
  static const String C_RIGHT__SMALL = "slds-p-right--small";
  static const String C_RIGHT__MEDIUM = "slds-p-right--medium";
  static const String C_RIGHT__LARGE = "slds-p-right--large";
  static const String C_RIGHT__X_LARGE = "slds-p-right--x-large";
  static const String C_BOTTOM__XXX_SMALL = "slds-p-bottom--xxx-small";
  static const String C_BOTTOM__XX_SMALL = "slds-p-bottom--xx-small";
  static const String C_BOTTOM__X_SMALL = "slds-p-bottom--x-small";
  static const String C_BOTTOM__SMALL = "slds-p-bottom--small";
  static const String C_BOTTOM__MEDIUM = "slds-p-bottom--medium";
  static const String C_BOTTOM__LARGE = "slds-p-bottom--large";
  static const String C_BOTTOM__X_LARGE = "slds-p-bottom--x-large";
  static const String C_LEFT__XXX_SMALL = "slds-p-left--xxx-small";
  static const String C_LEFT__XX_SMALL = "slds-p-left--xx-small";
  static const String C_LEFT__X_SMALL = "slds-p-left--x-small";
  static const String C_LEFT__SMALL = "slds-p-left--small";
  static const String C_LEFT__MEDIUM = "slds-p-left--medium";
  static const String C_LEFT__LARGE = "slds-p-left--large";
  static const String C_LEFT__X_LARGE = "slds-p-left--x-large";
  static const String C_VERTICAL__XXX_SMALL = "slds-p-vertical--xxx-small";
  static const String C_VERTICAL__XX_SMALL = "slds-p-vertical--xx-small";
  static const String C_VERTICAL__X_SMALL = "slds-p-vertical--x-small";
  static const String C_VERTICAL__SMALL = "slds-p-vertical--small";
  static const String C_VERTICAL__MEDIUM = "slds-p-vertical--medium";
  static const String C_VERTICAL__LARGE = "slds-p-vertical--large";
  static const String C_VERTICAL__X_LARGE = "slds-p-vertical--x-large";
  static const String C_HORIZONTAL__XXX_SMALL = "slds-p-horizontal--xxx-small";
  static const String C_HORIZONTAL__XX_SMALL = "slds-p-horizontal--xx-small";
  static const String C_HORIZONTAL__X_SMALL = "slds-p-horizontal--x-small";
  static const String C_HORIZONTAL__SMALL = "slds-p-horizontal--small";
  static const String C_HORIZONTAL__MEDIUM = "slds-p-horizontal--medium";
  static const String C_HORIZONTAL__LARGE = "slds-p-horizontal--large";
  static const String C_HORIZONTAL__X_LARGE = "slds-p-horizontal--x-large";
  static const String C_AROUND__XXX_SMALL = "slds-p-around--xxx-small";
  static const String C_AROUND__XX_SMALL = "slds-p-around--xx-small";
  static const String C_AROUND__X_SMALL = "slds-p-around--x-small";
  static const String C_AROUND__SMALL = "slds-p-around--small";
  static const String C_AROUND__MEDIUM = "slds-p-around--medium";
  static const String C_AROUND__LARGE = "slds-p-around--large";
  static const String C_AROUND__X_LARGE = "slds-p-around--x-large";

} // LPadding



class LTruncate {

  /// slds-truncate - Creates truncated text
  static const String C_TRUNCATE = "slds-truncate";
  /// slds-has-flexi-truncate - Allows truncation in nested flexbox containers
  static const String C_HAS_FLEXI_TRUNCATE = "slds-has-flexi-truncate";


  static const String C_COL = "slds-col";
  static const String C_COL__PADDED = "slds-col--padded";

}

==> lightning-0.12.1.tar.gz: lib/src/view/components/l_utilities.dart <==
/*
 * Copyright (c) 2015 Accorto, Inc. All Rights Reserved
 * License: GPLv3  http://www.gnu.org/licenses/gpl-3.0.txt
 * License options+support:  https://lightningdart.com
 */

part of lightning_dart;


/// Floats
class LFloat {

  /// slds-float--left: Pulls element from document flow and floats left. Text and other elements wrap around it.
  static const String C_FLOAT__LEFT = "slds-float--left";
  /// slds-float--right: Pulls element from document flow and floats right. Text and other elements wrap around it.
  static const String C_FLOAT__RIGHT = "slds-float--right";
  /// slds-clearfix: Contains floats and stops wrapping of elements following it. - Applies to parent of floats
  static const String C_CLEARFIX = "slds-clearfix";

} // LFloat


/// Sizing
class LSizing {

  static const String C_SIZE__1_OF_1 = "slds-size--1-of-1";

  static const String C_SIZE__1_OF_2 = "slds-size--1-of-2";

  static const String C_SIZE__1_OF_3 = "slds-size--1-of-3";
  static const String C_SIZE__2_OF_3 = "slds-size--2-of-3";

  static const String C_SIZE__1_OF_4 = "slds-size--1-of-4";
  static const String C_SIZE__2_OF_4 = "slds-size--2-of-4";
  static const String C_SIZE__3_OF_4 = "slds-size--3-of-4";

  static const String C_SIZE__1_OF_5 = "slds-size--1-of-5";
  static const String C_SIZE__2_OF_5 = "slds-size--2-of-5";
  static const String C_SIZE__3_OF_5 = "slds-size--3-of-5";
  static const String C_SIZE__4_OF_5 = "slds-size--4-of-5";

  static const String C_SIZE__1_OF_6 = "slds-size--1-of-6";
  static const String C_SIZE__2_OF_6 = "slds-size--2-of-6";
  static const String C_SIZE__3_OF_6 = "slds-size--3-of-6";
  static const String C_SIZE__4_OF_6 = "slds-size--4-of-6";
  static const String C_SIZE__5_OF_6 = "slds-size--5-of-6";

  static const String C_SIZE__1_OF_12 = "slds-size--1-of-12";
  static const String C_SIZE__2_OF_12 = "slds-size--2-of-12";
  static const String C_SIZE__3_OF_12 = "slds-size--3-of-12";
  static const String C_SIZE__4_OF_12 = "slds-size--4-of-12";
  static const String C_SIZE__5_OF_12 = "slds-size--5-of-12";
  static const String C_SIZE__6_OF_12 = "slds-size--6-of-12";
  static const String C_SIZE__7_OF_12 = "slds-size--7-of-12";
  static const String C_SIZE__8_OF_12 = "slds-size--8-of-12";
  static const String C_SIZE__9_OF_12 = "slds-size--9-of-12";
  static const String C_SIZE__10_OF_12 = "slds-size--10-of-12";
  static const String C_SIZE__11_OF_12 = "slds-size--11-of-12";

  /// default
  static const String C__SIZE__1_OF_ = "slds-size--1-of-";
  /// 30rem / 480px
  static const String C_SMALL_SIZE__1_OF_ = "slds-small-size--1-of-";
  /// 48rem / 768px
  static const String C_MEDIUM_SIZE__1_OF_ = "slds-medium-size--1-of-";
  /// 64rem / 1024px
  static const String C_LARGE_SIZE__1_OF_ = "slds-large-size--1-of-";


  static String sizeXofY(int x, int y) {
    return "slds-size--${x}-of-${y}";
  }
  static String sizeSmallXofY(int x, int y) {
    return "slds-small-size--${x}-of-${y}";
  }
  static String sizeMediumXofY(int x, int y) {
    return "slds-medium-size--${x}-of-${y}";
  }
  static String sizeLargeXofY(int x, int y) {
    return "slds-medium-size--${x}-of-${y}";
  }

  static String size1ofY(int y) {
    return "slds-size--1-of-${y}";
  }
  static String sizeSmall1ofY(int y) {
    return "slds-small-size--1-of-${y}";
  }
  static String sizeMedium1ofY( int y) {
    return "slds-medium-size--1-of-${y}";
  }
  static String sizeLarge1ofY(int y) {
    return "slds-medium-size--y-of-${y}";
  }

} // LSizing


/**
 * Margin
 */
class LMargin {

  static const String C_TOP__XXX_SMALL = "slds-m-top--xxx-small";
  static const String C_TOP__XX_SMALL = "slds-m-top--xx-small";
  static const String C_TOP__X_SMALL = "slds-m-top--x-small";
  static const String C_TOP__SMALL = "slds-m-top--small";
  static const String C_TOP__MEDIUM = "slds-m-top--medium";
  static const String C_TOP__LARGE = "slds-m-top--large";
  static const String C_TOP__X_LARGE = "slds-m-top--x-large";
  static const String C_RIGHT__XXX_SMALL = "slds-m-right--xxx-small";
  static const String C_RIGHT__XX_SMALL = "slds-m-right--xx-small";
  static const String C_RIGHT__X_SMALL = "slds-m-right--x-small";
  static const String C_RIGHT__SMALL = "slds-m-right--small";
  static const String C_RIGHT__MEDIUM = "slds-m-right--medium";
  static const String C_RIGHT__LARGE = "slds-m-right--large";
  static const String C_RIGHT__X_LARGE = "slds-m-right--x-large";
  static const String C_BOTTOM__XXX_SMALL = "slds-m-bottom--xxx-small";
  static const String C_BOTTOM__XX_SMALL = "slds-m-bottom--xx-small";
  static const String C_BOTTOM__X_SMALL = "slds-m-bottom--x-small";
  static const String C_BOTTOM__SMALL = "slds-m-bottom--small";
  static const String C_BOTTOM__MEDIUM = "slds-m-bottom--medium";
  static const String C_BOTTOM__LARGE = "slds-m-bottom--large";
  static const String C_BOTTOM__X_LARGE = "slds-m-bottom--x-large";
  static const String C_LEFT__XXX_SMALL = "slds-m-left--xxx-small";
  static const String C_LEFT__XX_SMALL = "slds-m-left--xx-small";
  static const String C_LEFT__X_SMALL = "slds-m-left--x-small";
  static const String C_LEFT__SMALL = "slds-m-left--small";
  static const String C_LEFT__MEDIUM = "slds-m-left--medium";
  static const String C_LEFT__LARGE = "slds-m-left--large";
  static const String C_LEFT__X_LARGE = "slds-m-left--x-large";
  static const String C_VERTICAL__XXX_SMALL = "slds-m-vertical--xxx-small";
  static const String C_VERTICAL__XX_SMALL = "slds-m-vertical--xx-small";
  static const String C_VERTICAL__X_SMALL = "slds-m-vertical--x-small";
  static const String C_VERTICAL__SMALL = "slds-m-vertical--small";
  static const String C_VERTICAL__MEDIUM = "slds-m-vertical--medium";
  static const String C_VERTICAL__LARGE = "slds-m-vertical--large";
  static const String C_VERTICAL__X_LARGE = "slds-m-vertical--x-large";
  static const String C_HORIZONTAL__XXX_SMALL = "slds-m-horizontal--xxx-small";
  static const String C_HORIZONTAL__XX_SMALL = "slds-m-horizontal--xx-small";
  static const String C_HORIZONTAL__X_SMALL = "slds-m-horizontal--x-small";
  static const String C_HORIZONTAL__SMALL = "slds-m-horizontal--small";
  static const String C_HORIZONTAL__MEDIUM = "slds-m-horizontal--medium";
  static const String C_HORIZONTAL__LARGE = "slds-m-horizontal--large";
  static const String C_HORIZONTAL__X_LARGE = "slds-m-horizontal--x-large";
  static const String C_AROUND__XXX_SMALL = "slds-m-around--xxx-small";
  static const String C_AROUND__XX_SMALL = "slds-m-around--xx-small";
  static const String C_AROUND__X_SMALL = "slds-m-around--x-small";
  static const String C_AROUND__SMALL = "slds-m-around--small";
  static const String C_AROUND__MEDIUM = "slds-m-around--medium";
  static const String C_AROUND__LARGE = "slds-m-around--large";
  static const String C_AROUND__X_LARGE = "slds-m-around--x-large";

} // LMargin


/**
 * Padding
 */
class LPadding {

  static const String C_TOP__XXX_SMALL = "slds-p-top--xxx-small";
  static const String C_TOP__XX_SMALL = "slds-p-top--xx-small";
  static const String C_TOP__X_SMALL = "slds-p-top--x-small";
  static const String C_TOP__SMALL = "slds-p-top--small";
  static const String C_TOP__MEDIUM = "slds-p-top--medium";
  static const String C_TOP__LARGE = "slds-p-top--large";
  static const String C_TOP__X_LARGE = "slds-p-top--x-large";
  static const String C_RIGHT__XXX_SMALL = "slds-p-right--xxx-small";
  static const String C_RIGHT__XX_SMALL = "slds-p-right--xx-small";
  static const String C_RIGHT__X_SMALL = "slds-p-right--x-small";
  static const String C_RIGHT__SMALL = "slds-p-right--small";
  static const String C_RIGHT__MEDIUM = "slds-p-right--medium";
  static const String C_RIGHT__LARGE = "slds-p-right--large";
  static const String C_RIGHT__X_LARGE = "slds-p-right--x-large";
  static const String C_BOTTOM__XXX_SMALL = "slds-p-bottom--xxx-small";
  static const String C_BOTTOM__XX_SMALL = "slds-p-bottom--xx-small";
  static const String C_BOTTOM__X_SMALL = "slds-p-bottom--x-small";
  static const String C_BOTTOM__SMALL = "slds-p-bottom--small";
  static const String C_BOTTOM__MEDIUM = "slds-p-bottom--medium";
  static const String C_BOTTOM__LARGE = "slds-p-bottom--large";
  static const String C_BOTTOM__X_LARGE = "slds-p-bottom--x-large";
  static const String C_LEFT__XXX_SMALL = "slds-p-left--xxx-small";
  static const String C_LEFT__XX_SMALL = "slds-p-left--xx-small";
  static const String C_LEFT__X_SMALL = "slds-p-left--x-small";
  static const String C_LEFT__SMALL = "slds-p-left--small";
  static const String C_LEFT__MEDIUM = "slds-p-left--medium";
  static const String C_LEFT__LARGE = "slds-p-left--large";
  static const String C_LEFT__X_LARGE = "slds-p-left--x-large";
  static const String C_VERTICAL__XXX_SMALL = "slds-p-vertical--xxx-small";
  static const String C_VERTICAL__XX_SMALL = "slds-p-vertical--xx-small";
  static const String C_VERTICAL__X_SMALL = "slds-p-vertical--x-small";
  static const String C_VERTICAL__SMALL = "slds-p-vertical--small";
  static const String C_VERTICAL__MEDIUM = "slds-p-vertical--medium";
  static const String C_VERTICAL__LARGE = "slds-p-vertical--large";
  static const String C_VERTICAL__X_LARGE = "slds-p-vertical--x-large";
  static const String C_HORIZONTAL__XXX_SMALL = "slds-p-horizontal--xxx-small";
  static const String C_HORIZONTAL__XX_SMALL = "slds-p-horizontal--xx-small";
  static const String C_HORIZONTAL__X_SMALL = "slds-p-horizontal--x-small";
  static const String C_HORIZONTAL__SMALL = "slds-p-horizontal--small";
  static const String C_HORIZONTAL__MEDIUM = "slds-p-horizontal--medium";
  static const String C_HORIZONTAL__LARGE = "slds-p-horizontal--large";
  static const String C_HORIZONTAL__X_LARGE = "slds-p-horizontal--x-large";
  static const String C_AROUND__XXX_SMALL = "slds-p-around--xxx-small";
  static const String C_AROUND__XX_SMALL = "slds-p-around--xx-small";
  static const String C_AROUND__X_SMALL = "slds-p-around--x-small";
  static const String C_AROUND__SMALL = "slds-p-around--small";
  static const String C_AROUND__MEDIUM = "slds-p-around--medium";
  static const String C_AROUND__LARGE = "slds-p-around--large";
  static const String C_AROUND__X_LARGE = "slds-p-around--x-large";

} // LPadding


/**
 * Truncation
 */
class LTruncate {

  /// slds-truncate (any element): Creates truncated text - Truncation will occur at the parent width if a width is not specified
  static const String C_TRUNCATE = "slds-truncate";
  /// slds-has-flexi-truncate (.slds-col--padded): Allows truncation in nested flexbox containers - This class is placed on a parent element that contains a flexbox element containing .slds-truncate. For example — for a media object that is nested in a grid column and contains truncation — the grid column would require this class.
  static const String C_HAS_FLEXI_TRUNCATE = "slds-has-flexi-truncate";

}
